# C++ `this`指针

> 原文： [https://beginnersbook.com/2017/08/cpp-this-pointer/](https://beginnersbook.com/2017/08/cpp-this-pointer/)

`this`指针保存当前对象的地址，简单来说，你可以说这个[指针](https://beginnersbook.com/2017/08/cpp-pointers/)指向该类的当前对象。让我们举个例子来理解这个概念。

## C++ 示例：`this`指针

在这里你可以看到我们有两个数据成员`num`和`ch`。在成员函数`setMyValues()`中，我们有两个与数据成员名称相同的局部变量。在这种情况下，如果要将局部变量值赋值给数据成员，那么除非使用`this`指针，否则您将无法执行此操作，因为除非您使用`this`，否则编译器将不知道您指的是对象的数据成员。这是必须使用`this`指针的示例之一。

```cpp
#include <iostream>
using namespace std;
class Demo {
private:
  int num;
  char ch;
public:
  void setMyValues(int num, char ch){
    this->num =num;
    this->ch=ch;
  }
  void displayMyValues(){
    cout<<num<<endl;
    cout<<ch;
  }
};
int main(){
  Demo obj;
  obj.setMyValues(100, 'A');
  obj.displayMyValues();
  return 0;
}
```

**输出：**

```cpp
100
A
```

## 示例 2：使用`this`指针进行函数链式调用

使用`this`指针的另一个示例是返回当前对象的引用，以便您可以链式调用函数，这样您就可以一次调用当前对象的所有函数。在这个程序中需要注意的另一个要点是，我在第二个函数中增加了对象`num`的值，你可以在输出中看到它实际上增加了我们在第一个函数调用中设置的值。这表明链接是顺序的，对对象的数据成员所做的更改将保留以进一步链式调用。

```cpp
#include <iostream>
using namespace std;
class Demo {
private:
  int num;
  char ch;
public:
  Demo &setNum(int num){
    this->num =num;
    return *this;
  }
  Demo &setCh(char ch){
    this->num++;
    this->ch =ch;
    return *this;
  }
  void displayMyValues(){
    cout<<num<<endl;
    cout<<ch;
  }
};
int main(){
  Demo obj;
  //Chaining calls
  obj.setNum(100).setCh('A');
  obj.displayMyValues();
  return 0;
}
```

**输出：**

```cpp
101
A
```