# 如何在 Java 中检查文件是否隐藏

> 原文： [https://beginnersbook.com/2015/01/how-to-check-if-a-file-is-hidden-in-java/](https://beginnersbook.com/2015/01/how-to-check-if-a-file-is-hidden-in-java/)

在本教程中，我们将学习如何编写程序来检查特定文件是否被隐藏。我们将使用`File`类的`isHidden()`方法来执行此检查。此方法返回布尔值（`true`或`false`），如果文件被隐藏，则此方法返回`true`，否则返回`false`值。

#### 这是完整的代码：

```java
import java.io.File;
import java.io.IOException;

public class HiddenPropertyCheck
{

    public static void main(String[] args) throws IOException, SecurityException
    {	
    	// Provide the complete file path here
    	File file = new File("c:/myfile.txt");

    	if(file.isHidden()){
    		System.out.println("The specified file is hidden");
    	}else{
    		System.out.println("The specified file is not hidden");
    	}
    }
}

```

#### 关于 [javadoc](https://docs.oracle.com/javase/7/docs/api/java/nio/file/Files.html) 的`isHidden()`方法的更多细节：

```java
public static boolean isHidden(Path path) throws IOException
```

判断文件是否被视为隐藏。隐藏的确切定义是平台或提供者依赖。例如，在 UNIX 上，如果文件的名称以句点字符（`'.'`）开头，则认为该文件是隐藏的。在 Windows 上，如果文件不是目录并且设置了 DOS 隐藏属性，则该文件被视为隐藏。
根据实现方式，此方法可能需要访问文件系统以确定文件是否被视为隐藏。

**参数：**

`path` - 要测试的文件的路径

**返回：**

如果文件被视为隐藏，则返回`true`

**抛出：**

`IOException` - 如果发生 I/O 错误

`SecurityException` - 如果是默认提供程序，并且安装了安全管理器，则调用`checkRead`方法以检查对文件。