# java 的多态类型 - 运行时和编译时多态

> 原文： [https://beginnersbook.com/2013/04/runtime-compile-time-polymorphism/](https://beginnersbook.com/2013/04/runtime-compile-time-polymorphism/)

在上一篇教程中，我们讨论了 Java 中的[多态。在本指南中，我们将看到**类型的多态**。 java 中有两种类型的多态：

1）**静态多态**又称编译时多态

2）**动态多态**又称运行时多态](https://beginnersbook.com/2013/03/polymorphism-in-java/)

## 编译时多态（或静态多态）

在编译器时间内解析的多态称为静态多态。方法重载是编译时多态的一个例子。
**方法重载**：如果方法的参数在参数的数量，顺序和数据类型上不同，这允许我们有多个具有相同名称的方法。我们在这里已经讨论了方法重载：如果你没有阅读该指南，请参考： [Java 中的方法重载](https://beginnersbook.com/2013/05/method-overloading/)

### 静态多态的例子

方法重载是 java 支持静态多态的方式之一。这里我们有两个相同方法`add()`的定义，其中`add`方法将在编译时由参数列表确定。这就是为什么它也被称为编译时多态。

```java
class SimpleCalculator
{
    int add(int a, int b)
    {
         return a+b;
    }
    int  add(int a, int b, int c)  
    {
         return a+b+c;
    }
}
public class Demo
{
   public static void main(String args[])
   {
	   SimpleCalculator obj = new SimpleCalculator();
       System.out.println(obj.add(10, 20));
       System.out.println(obj.add(10, 20, 30));
   }
}

```

**输出：**

```java
30
60

```

## 运行时多态（或动态多态）

它也称为动态方法调度。动态多态是一个在运行时解析对重写方法的调用的过程，这就是为什么它被称为运行时多态。我已经在单独的教程中详细讨论了方法覆盖，请参考：[方法覆盖 Java](https://beginnersbook.com/2014/01/method-overriding-in-java-with-example/) 。

**示例**

在此示例中，我们有两个类`ABC`和`XYZ`。`ABC`是父类，`XYZ`是子类。子类覆盖父类的`myMethod()`方法。在此示例中，我们将子类对象分配给父类引用，因此为了确定将调用哪个方法，将在运行时确定对象的类型。对象的类型决定了要调用哪个版本的方法（而不是引用的类型）。

> 要理解覆盖的概念，您应该具有 Java 中[继承的基本知识](https://beginnersbook.com/2013/03/inheritance-in-java/)。

```java
class ABC{
   public void myMethod(){
	System.out.println("Overridden Method");
   }
}
public class XYZ extends ABC{

   public void myMethod(){
	System.out.println("Overriding Method");
   }
   public static void main(String args[]){
	ABC obj = new XYZ();
	obj.myMethod();
   }
}
```

**输出：**

```java
Overriding Method
```

当通过父类的引用调用重写方法时，该对象的类型确定要执行哪个方法。因此，该确定在运行时进行。
由于两个类，子类和父类具有相同的方法`animalSound`。将在运行时由 JVM 确定将调用哪个版本的方法（子类或父类）。

**几个最重要的例子：**

```java
ABC obj = new ABC();
obj.myMethod();
// This would call the myMethod() of parent class ABC

XYZ obj = new XYZ();
obj.myMethod();
// This would call the myMethod() of child class XYZ

ABC obj = new XYZ();
obj.myMethod();
// This would call the myMethod() of child class XYZ

```

在第三种情况下，要执行子类的方法，因为要执行的方法由对象的类型决定，并且由于对象属于子类，因此调用`myMethod()`的子类版本。