# Java 中的运算符

> 原文： [https://beginnersbook.com/2017/08/operators-in-java/](https://beginnersbook.com/2017/08/operators-in-java/)

运算符是**表示动作**的字符，例如`+`是表示加法的算术运算符。

## Java 中的运算符类型

1）基本算术运算符

2）赋值运算符

3）自增和自减运算符

4）逻辑运算符

5）比较（关系）运算符

6）位运算符

7）三元运算符

## 1）基本算术运算符

基本算术运算符是：`+， - ，*，/，%`。

+   `+`用于加法。

+   `-`用于减法。

+   `*`用于乘法。

+   `/`用于除法。

+   `%`用于模数。

注意：模运算符返回余数，例如`10%5`将返回 0。

### 算术运算符的例子

```java
public class ArithmeticOperatorDemo {
   public static void main(String args[]) {
      int num1 = 100;
      int num2 = 20;

      System.out.println("num1 + num2: " + (num1 + num2) );
      System.out.println("num1 - num2: " + (num1 - num2) );
      System.out.println("num1 * num2: " + (num1 * num2) ); 
      System.out.println("num1 / num2: " + (num1 / num2) );
      System.out.println("num1 % num2: " + (num1 % num2) );
   }
}

```

**输出：**

```java
num1 + num2: 120
num1 - num2: 80
num1 * num2: 2000
num1 / num2: 5
num1 % num2: 0

```

查看与 Java 中的算术运算符相关的这些 [java 程序](https://beginnersbook.com/2017/09/java-examples/)：

1.  [Java 程序：添加两个数字](https://beginnersbook.com/2017/09/java-program-to-add-two-numbers/)
2.  [Java 程序：乘以两个数字](https://beginnersbook.com/2017/09/java-program-to-multiply-two-numbers/)

## 2）赋值运算符

java 中的赋值运算符是：`=，+ =， - =，* =，/ =，%=`。

+   `num2 = num1`将变量`num1`的值赋给变量

+   `num2 + = num1`等于`num2 = num2 + num1`

+   `num2- = num1`等于`num2 = num2-num1`

+   `num2 * = num1`等于`num2 = num2 * num1`

+   `num2 / = num1`等于`num2 = num2 / num1`

+   `num2%= num1`等于`num2 = num2%num1`

### 赋值运算符的示例

```java
public class AssignmentOperatorDemo {
   public static void main(String args[]) {
      int num1 = 10;
      int num2 = 20;

      num2 = num1;
      System.out.println("= 输出： "+num2);

      num2 += num1;
      System.out.println("+= 输出： "+num2);

      num2 -= num1;
      System.out.println("-= 输出： "+num2);

      num2 *= num1;
      System.out.println("*= 输出： "+num2);

      num2 /= num1;
      System.out.println("/= 输出： "+num2);

      num2 %= num1;
      System.out.println("%= 输出： "+num2);
   }
}

```

**输出：**

```java
= 输出： 10
+= 输出： 20
-= 输出： 10
*= 输出： 100
/= 输出： 10
%= 输出： 0

```

## 3）自增和自减运算符

`++`和`--`：

+   `num++`相当于`num=num+1;`

+   `num--`相当于`num=num-1;`

### 自增和自减运算符的示例

```java
public class AutoOperatorDemo {
   public static void main(String args[]){
      int num1=100;
      int num2=200;
      num1++;
      num2--;
      System.out.println("num1++ is: "+num1);
      System.out.println("num2-- is: "+num2);
   }
}

```

**输出：**

```java
num1++ is: 101
num2-- is: 199
```

## 4）逻辑运算符

逻辑运算符与二进制变量一起使用。它们主要用于条件语句和循环以求值条件。

java 中的逻辑运算符是：`&& || !`。

假设我们有两个布尔变量`b1`和`b2`。

如果`b1`和`b2`都为真，则`b1 && b2`将返回`true`，否则它将返回`false`。

如果`b1`和`b2`都为假，则`*b1 || b2`将返回`false`，否则返回`true`。

`!b1`将返回与`b1`相反的位置，这意味着如果`b1`为假则为真，如果`b1`为真则返回`false`。

### 逻辑运算符的示例

```java
public class LogicalOperatorDemo {
   public static void main(String args[]) {
      boolean b1 = true;
      boolean b2 = false;

      System.out.println("b1 && b2: " + (b1&&b2));
      System.out.println("b1 || b2: " + (b1||b2));
      System.out.println("!(b1 && b2): " + !(b1&&b2));
   }
}

```

**输出：**

```java
b1 && b2: false
b1 || b2: true
!(b1 && b2): true

```

## 5）比较（关系）运算符

我们在 Java 中有六个关系运算符：`== != > < >= <=`。

+   如果左侧和右侧都相等，则`==`返回`true`。

+   如果左侧不等于运算符的右侧，则`!=`返回`true`。

+   如果左侧大于右侧，`>`返回`true`。

+   如果左侧小于右侧，`<`返回`true`。

+   如果左侧大于或等于右侧，则`>=`返回`true`。

+   如果左侧小于或等于右侧，则`<=`返回`true`。

### 关系运算符的示例

**注意：**这个例子使用`if-else`语句，这是我们的下一个教程，如果你发现它很难理解，那么在 Java 中引用[`if-else`](https://beginnersbook.com/2017/08/if-else-statement-in-java/)。

```java
public class RelationalOperatorDemo {
   public static void main(String args[]) {
      int num1 = 10;
      int num2 = 50;
      if (num1==num2) {
	 System.out.println("num1 and num2 are equal");
      }
      else{
	 System.out.println("num1 and num2 are not equal");
      }

      if( num1 != num2 ){
	 System.out.println("num1 and num2 are not equal");
      }
      else{
	 System.out.println("num1 and num2 are equal");
      }

      if( num1 > num2 ){
	 System.out.println("num1 is greater than num2");
      }
      else{
	 System.out.println("num1 is not greater than num2");
      }

      if( num1 >= num2 ){
	 System.out.println("num1 is greater than or equal to num2");
      }
      else{
	 System.out.println("num1 is less than num2");
      }

      if( num1 < num2 ){
	 System.out.println("num1 is less than num2");
      }
      else{
	 System.out.println("num1 is not less than num2");
      }

      if( num1 <= num2){
	 System.out.println("num1 is less than or equal to num2");
      }
      else{
	 System.out.println("num1 is greater than num2");
      }
   }
}

```

**输出：**

```java
num1 and num2 are not equal
num1 and num2 are not equal
num1 is not greater than num2
num1 is less than num2
num1 is less than num2
num1 is less than or equal to num2

```

看看这些与关系运算符相关的 java 程序：

1.  [Java 程序：检查数字是正数还是负数](https://beginnersbook.com/2017/09/java-program-to-check-if-number-is-positive-or-negative/)
2.  [Java 程序：检查数字是偶数还是奇数](https://beginnersbook.com/2017/09/cpp-program-to-check-whether-the-input-number-is-even-or-odd/)

## 6）按位运算符

有六个按位运算符：`& | ^ ~ << >>`

```java
num1 = 11; /*等于 00001011 */
num2 = 22; /*等于 00010110 */
```

按位运算符执行逐位处理。
`num1 & num2`比较`num1`和`num2`的相应位，如果两个位相等则生成 1，否则返回 0.在我们的例子中它将返回：2，这是`00000010`，因为在`num1`和`num2`的二进制形式中，只有倒数第二位是匹配。

`num1 | num2`比较`num1`和`num2`的相应位，如果任一位为 1，则生成 1，否则返回 0.在我们的例子中，它将返回 31，即`00011111`。

`num1 ^ num2`比较`num1`和`num2`的相应位，如果它们不相等则生成 1，否则返回 0.在我们的例子中它将返回 29，相当于`00011101`。

`~num1`是一个补码运算符，只是将位从 0 更改为 1，1 更改为 0.在我们的示例中，它将返回-12，其中 8 位等效于`11110100`。

`num1 << 2`是左移位运算符，它将位移到左边，丢弃最左边的位，并将最右边的位赋值为 0.在我们的例子中，输出为 44，相当于`00101100`。

> 注意：在下面的示例中，我们在此移位运算符的右侧提供 2，这是位向左移动两个位置的原因。我们可以更改此数字，并且位将按运算符右侧指定的位数移动。同样适用于右侧运算符。

`num1 >> 2`是右移位运算符，它将位向右移动，丢弃最右位，并将最左边的位指定为 0.在我们的例子中，输出为 2，相当`00000010`。

### 按位运算符的示例

```java
public class BitwiseOperatorDemo {
  public static void main(String args[]) {

     int num1 = 11;  /* 11 = 00001011 */
     int num2 = 22;  /* 22 = 00010110 */
     int result = 0;

     result = num1 & num2;   
     System.out.println("num1 & num2: "+result);

     result = num1 | num2;   
     System.out.println("num1 | num2: "+result);

     result = num1 ^ num2;   
     System.out.println("num1 ^ num2: "+result);

     result = ~num1;   
     System.out.println("~num1: "+result);

     result = num1 << 2;   
     System.out.println("num1 << 2: "+result); result = num1 >> 2;   
     System.out.println("num1 >> 2: "+result);
  }
}

```

**输出：**

```java
num1 & num2: 2
num1 | num2: 31
num1 ^ num2: 29
~num1: -12
num1 << 2: 44 num1 >> 2: 2

```

查看这个程序： [Java 程序：使用按位运算符交换两个数字](https://beginnersbook.com/2017/09/java-program-to-swap-two-numbers-using-bitwise-xor-operator/)

## 7）三元运算符

此运算符计算布尔表达式并根据结果分配值。

**语法：**

```java
variable num1 = (expression) ? value if true : value if false
```

如果表达式结果为`true`，则将冒号（`:`）之前的第一个值分配给变量`num1`，否则将第二个值分配给`num1`。

### 三元运算符的例子

```java
public class TernaryOperatorDemo {

   public static void main(String args[]) {
        int num1, num2;
        num1 = 25;
        /* num1 is not equal to 10 that's why
	 * the second value after colon is assigned
	 * to the variable num2
	 */
	num2 = (num1 == 10) ? 100: 200;
	System.out.println( "num2: "+num2);

	/* num1 is equal to 25 that's why
	 * the first value is assigned
	 * to the variable num2
	 */
	num2 = (num1 == 25) ? 100: 200;
	System.out.println( "num2: "+num2);
   }
}

```

**输出：**

```java
num2: 200
num2: 100

```

看看这些相关的 java 程序：

1.  [使用三元运算符](https://beginnersbook.com/2017/09/java-program-to-find-largest-of-three-numbers-using-ternary-operator/)查找三个数字中最大的 Java 程序
2.  [Java 程序：使用三元运算符](https://beginnersbook.com/2017/09/java-program-to-find-the-smallest-of-three-numbers-using-ternary-operator/)查找三个最小的数字

## Java 中的运算符优先级

如果表达式具有多个运算符，则确定首先需要对哪个运算符求值。操作符在顶部具有较高优先级，在底部具有较低优先级。

一元运算符

`++ -- ! ~`

乘法

`* / %`

加法

`+ -`

移位

`<< >> >>>`

关系
`< <= > >=`

相等

`== !=`

位 AND

`&`

位异或

`^`

位 OR

`|`

逻辑 AND

`&&`

逻辑 OR

`||`

三元

`?:`

赋值

`= += -= *= /= %= >>= <<= &= ^= |=`