# Kotlin 关键词，软关键词和标识符

> 原文： [https://beginnersbook.com/2017/12/kotlin-keywords-identifiers/](https://beginnersbook.com/2017/12/kotlin-keywords-identifiers/)

Kotlin 中的某些单词具有特殊含义，不能用作标识符（变量名，函数名，类名等）。这些词被称为保留词或关键词。在本指南中，我们将了解**关键字和标识符**。

## Kotlin 中关键词的类型

我们有两种类型的关键字：

1.  硬关键字
2.  软关键字

### 1.硬关键词

这些关键字不能用作标识符。例如

**这是有效的：**

```kotlin
//valid variable name
val myvar = 5
```

**这是无效的：**

```kotlin
//error: "else" cannot be used as a variable name
val else = 5
```

| | | | | | |
| --- | --- | --- | --- | --- | --- |
| as | class | break | continue | do | else |
| for | fun | false | if | in | interface |
| super | return | object | package | null | is |
| try | throw | true | this | typeof | typealias |
| when | while | val | var |

### 2.软关键词

软关键字是仅在特定上下文中使用的关键字，这意味着我们可以将它们用作标识符。除了上面的关键字列表，还有其他关键字可以用作标识符。例如，`by`是一个软关键字，它将接口的实现委托给另一个对象。我们也可以使用关键字`by`作为标识符。

```kotlin
//valid code
fun main(args: Array) {
    val by=10
    println(by+10)
}
```

Kotlin 还有其他一些软关键词，如`catch`，`get`，`finally`，`field`等。

## Kotlin 标识符

我们给变量，类，函数等的名称称为标识符。例如：

```kotlin
var num = 100
```

这里`num`是一个标识符。

### Kotlin 标识符的命名约定

1.  标识符不能有空格。
2.  Kotlin 中的标识符区分大小写。
3.  它们不能包含特殊字符，如`@`，`#`，`%`等。
4.  标识符可以以下划线“_”开头。
5.  最佳做法是为标识符指定有意义的名称。例如：`add`，`multiply`和`divide`是比`a`，`m`和`d`更有意义的标识符。
6.  如果您希望在标识符中包含两个单词，则可以使用大写字母开头第二个单词。例如，`sumOfTwo`。

#### 参考

[Kotlin 文档 - 关键词参考](https://kotlinlang.org/docs/reference/keyword-reference.html)